@@ -91,14 +91,14 @@ class DelegatedUserManager {
                 ':parent_username' => $data['parent_username'],
                 ':display_name' => $data['display_name'] ?? null,
                 ':email' => $data['email'] ?? null,
-                ':can_manage_domains' => $data['can_manage_domains'] ?? false,
-                ':can_manage_sites' => $data['can_manage_sites'] ?? false,
-                ':can_manage_databases' => $data['can_manage_databases'] ?? false,
-                ':can_manage_email' => $data['can_manage_email'] ?? false,
-                ':can_manage_files' => $data['can_manage_files'] ?? false,
-                ':can_manage_backups' => $data['can_manage_backups'] ?? false,
-                ':can_view_terminal' => $data['can_view_terminal'] ?? false,
-                ':can_manage_wordpress' => $data['can_manage_wordpress'] ?? false,
+                ':can_manage_domains' => ($data['can_manage_domains'] ?? false) ? 1 : 0,
+                ':can_manage_sites' => ($data['can_manage_sites'] ?? false) ? 1 : 0,
+                ':can_manage_databases' => ($data['can_manage_databases'] ?? false) ? 1 : 0,
+                ':can_manage_email' => ($data['can_manage_email'] ?? false) ? 1 : 0,
+                ':can_manage_files' => ($data['can_manage_files'] ?? false) ? 1 : 0,
+                ':can_manage_backups' => ($data['can_manage_backups'] ?? false) ? 1 : 0,
+                ':can_view_terminal' => ($data['can_view_terminal'] ?? false) ? 1 : 0,
+                ':can_manage_wordpress' => ($data['can_manage_wordpress'] ?? false) ? 1 : 0,
                 ':allowed_domains' => isset($data['allowed_domains']) ? json_encode($data['allowed_domains']) : null,
                 ':max_domains' => $data['max_domains'] ?? null,
                 ':max_databases' => $data['max_databases'] ?? null,
@@ -341,11 +341,21 @@ class DelegatedUserManager {
             $update_fields = [];
             $params = [':id' => $user_id];
             
+            // Boolean fields that need conversion to integers
+            $boolean_fields = [
+                'can_manage_domains', 'can_manage_sites', 'can_manage_databases',
+                'can_manage_email', 'can_manage_files', 'can_manage_backups',
+                'can_view_terminal', 'can_manage_wordpress', 'is_active'
+            ];
+            
             foreach ($allowed_fields as $field) {
                 if (array_key_exists($field, $data)) {
                     $update_fields[] = "$field = :$field";
                     if ($field === 'allowed_domains' && is_array($data[$field])) {
                         $params[":$field"] = json_encode($data[$field]);
+                    } elseif (in_array($field, $boolean_fields)) {
+                        // Convert boolean to integer for MySQL TINYINT columns
+                        $params[":$field"] = $data[$field] ? 1 : 0;
                     } else {
                         $params[":$field"] = $data[$field];
                     }
