@@ -31,6 +31,21 @@ class security_wrapper {
         // Sanitize user input to prevent command injection
         $user = escapeshellarg($user);
         $homedir = trim(shell_exec("cat /etc/passwd |grep $user |awk -F ':' {'print \$6'}|head -1"));
+        
+        // If homedir is empty or not found, try to construct it based on username
+        if (empty($homedir)) {
+            // For root user, use /root
+            if ($user === "'root'" || $user === "root") {
+                $homedir = '/root';
+            } else {
+                // For regular users in WHP, use /docker/users/username pattern
+                // Remove quotes from escapeshellarg for path construction
+                $clean_user = trim($user, "'");
+                $homedir = '/docker/users/' . $clean_user;
+            }
+            error_log("Warning: Could not find home directory for user $user in /etc/passwd, using fallback: $homedir");
+        }
+        
         $this->homedir = $homedir;
         return $homedir;
     }
