@@ -114,20 +114,27 @@ class security_manager {
         
         // Record successful login if username is provided
         if (!empty($username)) {
+            // Ensure table exists before trying to use it
+            $this->ensure_successful_logins_table();
+            
             // Insert new login record
             $stmt = $this->db->prepare('INSERT INTO successful_logins (username, ip_address, login_time, user_agent) VALUES (:user, :ip, :time, :agent)');
-            $stmt->bindValue(':user', $username, SQLITE3_TEXT);
-            $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
-            $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
-            $stmt->bindValue(':agent', $user_agent, SQLITE3_TEXT);
-            $stmt->execute();
-            
-            // Keep only the last 3 logins for this user
-            $stmt = $this->db->prepare('DELETE FROM successful_logins WHERE username = :user AND id NOT IN (
-                SELECT id FROM successful_logins WHERE username = :user ORDER BY login_time DESC LIMIT 3
-            )');
-            $stmt->bindValue(':user', $username, SQLITE3_TEXT);
-            $stmt->execute();
+            if ($stmt) {
+                $stmt->bindValue(':user', $username, SQLITE3_TEXT);
+                $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
+                $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
+                $stmt->bindValue(':agent', $user_agent, SQLITE3_TEXT);
+                $stmt->execute();
+                
+                // Keep only the last 3 logins for this user
+                $stmt = $this->db->prepare('DELETE FROM successful_logins WHERE username = :user AND id NOT IN (
+                    SELECT id FROM successful_logins WHERE username = :user ORDER BY login_time DESC LIMIT 3
+                )');
+                if ($stmt) {
+                    $stmt->bindValue(':user', $username, SQLITE3_TEXT);
+                    $stmt->execute();
+                }
+            }
         }
         
         return true;
@@ -295,7 +302,13 @@ class security_manager {
     }
     
     public function get_last_logins($username) {
+        $this->ensure_successful_logins_table();
+        
         $stmt = $this->db->prepare('SELECT * FROM successful_logins WHERE username = :user ORDER BY login_time DESC LIMIT 3');
+        if (!$stmt) {
+            return array(); // Return empty array if table doesn't exist
+        }
+        
         $stmt->bindValue(':user', $username, SQLITE3_TEXT);
         $result = $stmt->execute();
         
@@ -308,7 +321,13 @@ class security_manager {
     }
     
     public function get_all_recent_logins($limit = 10) {
+        $this->ensure_successful_logins_table();
+        
         $stmt = $this->db->prepare('SELECT * FROM successful_logins ORDER BY login_time DESC LIMIT :limit');
+        if (!$stmt) {
+            return array(); // Return empty array if table doesn't exist
+        }
+        
         $stmt->bindValue(':limit', $limit, SQLITE3_INTEGER);
         $result = $stmt->execute();
         
