@@ -69,6 +69,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
 $blocked_ips = $SecManager->get_blocked_ips();
 $whitelist_ips = $SecManager->get_whitelist_ips();
 $security_stats = $SecManager->get_security_stats();
+$recent_logins = $SecManager->get_all_recent_logins(10);
 
 // Get access statistics
 require_once('/docker/whp/web/libs/permission_manager.php');
@@ -290,4 +291,67 @@ $access_stats = $PermManager->get_system_access_stats(30);
             </div>
         </div>
     </div>
+</div>
+
+<!-- Recent Successful Logins -->
+<div class="row g-4 mt-4">
+    <div class="col-md-12">
+        <div class="card">
+            <div class="card-header">
+                <h5 class="card-title mb-0">Recent Successful Logins</h5>
+            </div>
+            <div class="card-body">
+                <div class="table-responsive">
+                    <table class="table table-striped table-hover">
+                        <thead class="table-dark">
+                            <tr>
+                                <th>Username</th>
+                                <th>IP Address</th>
+                                <th>Login Time</th>
+                                <th>User Agent</th>
+                            </tr>
+                        </thead>
+                        <tbody>
+                            <?php if (empty($recent_logins)): ?>
+                            <tr>
+                                <td colspan="4" class="text-center text-muted">No recent logins found</td>
+                            </tr>
+                            <?php else: ?>
+                            <?php foreach ($recent_logins as $login): ?>
+                            <tr>
+                                <td><strong><?php echo htmlspecialchars($login['username']); ?></strong></td>
+                                <td>
+                                    <code><?php echo htmlspecialchars($login['ip_address']); ?></code>
+                                </td>
+                                <td>
+                                    <span title="<?php echo date('Y-m-d H:i:s', $login['login_time']); ?>">
+                                        <?php 
+                                        $time_ago = time() - $login['login_time'];
+                                        if ($time_ago < 60) {
+                                            echo 'Just now';
+                                        } elseif ($time_ago < 3600) {
+                                            echo floor($time_ago / 60) . ' minutes ago';
+                                        } elseif ($time_ago < 86400) {
+                                            echo floor($time_ago / 3600) . ' hours ago';
+                                        } else {
+                                            echo floor($time_ago / 86400) . ' days ago';
+                                        }
+                                        ?>
+                                    </span>
+                                </td>
+                                <td class="text-truncate" style="max-width: 300px;" title="<?php echo htmlspecialchars($login['user_agent'], ENT_QUOTES, 'UTF-8'); ?>">
+                                    <?php 
+                                    $user_agent = htmlspecialchars($login['user_agent'], ENT_QUOTES, 'UTF-8');
+                                    echo strlen($user_agent) > 60 ? substr($user_agent, 0, 60) . '...' : $user_agent; 
+                                    ?>
+                                </td>
+                            </tr>
+                            <?php endforeach; ?>
+                            <?php endif; ?>
+                        </tbody>
+                    </table>
+                </div>
+            </div>
+        </div>
+    </div>
 </div> 
\ No newline at end of file
